# eric7.MicroPython.ShowModulesDialog

Module implementing a dialog to show the available modules of all bundles.

### Global Attributes

None

### Classes

ShowModulesDialog | Class implementing a dialog to show the available modules of all bundles.

### Functions

None

## ShowModulesDialog

Class implementing a dialog to show the available modules of all bundles.

### Derived from

QDialog, Ui_ShowModulesDialog

### Class Attributes

None

### Class Methods

None

### Methods

ShowModulesDialog | Constructor
__applyFilter | Private slot to apply the filter to the list of available modules.
__checkCountUpdated | Private method to handle an update of the check count.
getSelection | Public method to get the list of selected modules.
on_modulesList_itemChanged | Private slot to handle a change of the check state of an item.

### Static Methods

None

#### ShowModulesDialog (Constructor)

ShowModulesDialog(modulesList, selectionMode=False, info="", parent=None)

Constructor

modulesList (list of str)
  list of module names to be shown
selectionMode (bool (optional))
  flag indicating the activation of the selection mode (defaults to False)
info (str (optional))
  string containing some informational data (defaults to "")
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### ShowModulesDialog.__applyFilter

__applyFilter()

Private slot to apply the filter to the list of available modules.

#### ShowModulesDialog.__checkCountUpdated

__checkCountUpdated()

Private method to handle an update of the check count.

#### ShowModulesDialog.getSelection

getSelection()

Public method to get the list of selected modules.

Return:
  list of selected modules

Return Type:
  circup.Module

#### ShowModulesDialog.on_modulesList_itemChanged

on_modulesList_itemChanged(item)

Private slot to handle a change of the check state of an item.

item (QTreeWidgetItem)
  reference to the changed item

Up